import csv
import json
from collections import OrderedDict


class CsvJson:
    def __init__(self, sort_columns=False, pretty_print = False):
        self.sort_columns = sort_columns
        self.indent = 4 if pretty_print else None

    def convert(self, csv_data):
        reader = csv.DictReader(csv_data, delimiter=",")
        rows = []
        for row in reader:
            if self.sort_columns:
                rows.append(row)
            else:
                unsorted_row = OrderedDict(sorted(row.items(),
                                                  key=lambda item: reader.fieldnames.index(item[0])))
                rows.append(unsorted_row)
        return json.dumps(rows, sort_keys=self.sort_columns, indent=self.indent)



import argparse
import sys
from argparse import ArgumentParser

from dsfkit.utilities import csvjson


def main():
    parser = ArgumentParser()
    parser.add_argument('csv_file', metavar='CSV_FILE', nargs='?', type=argparse.FileType('r'),
                        default=sys.stdin, help='CSV file (if empty stdin is used)')
    parser.add_argument('json_file', metavar='JSON_FILE', nargs='?', type=argparse.FileType('w'),
                        default=sys.stdout, help='JSON file (if empty, stdout is used)')
    parser.add_argument('--sort', help = "Sort JSON output", action="store_true")
    parser.add_argument('--pretty', help="Pretty print JSON output", action="store_true")
    args = parser.parse_args()

    csv_json = csvjson.CsvJson(sort_columns=args.sort, pretty_print=args.pretty)
    args.json_file.write(csv_json.convert(args.csv_file))
    args.json_file.write('\n')
    args.json_file.flush()
    args.json_file.close()


if __name__ == '__main__':
    main()
